pub struct RangedInteger<const MIN: i32, const MAX: i32> { /* private fields */ }Expand description
A simple struct for wrapping an i32 with const generic parameters to limit
the range of allowed values.
Implementations
Sourceimpl<const MIN: i32, const MAX: i32> RangedInteger<MIN, MAX>
impl<const MIN: i32, const MAX: i32> RangedInteger<MIN, MAX>
Sourcepub fn new(value: i32) -> Self
pub fn new(value: i32) -> Self
Makes a new ranged integer if the value is in the allowed range, otherwise panics.
Sourcepub fn range() -> RangeInclusive<i32>
pub fn range() -> RangeInclusive<i32>
Gets the range of allowed values as an inclusive range, constructed from the generic parameters.
Sourcepub fn random_value() -> i32
pub fn random_value() -> i32
Gets a random value that is in the range of allowed values.